==> openjdk-17_17.0.17~8ea.orig.tar.xz: openjdk-17-17.0.17~8ea/test/hotspot/jtreg/vmTestbase/nsk/share/runner/MemDiag.java <==
/*
 * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package nsk.share.runner;

/**
 *  Helper that prints memory information.
 */
public class MemDiag implements Runnable {
        private long sleepTime;

        public MemDiag() {
                this(RunParams.getInstance().getSleepTime());
        }

        public MemDiag(long sleepTime) {
                this.sleepTime = sleepTime;
        }

        public void run() {
                System.out.println(Runtime.getRuntime().freeMemory());
                // Ensure that interrupt status is not lost
                if (Thread.currentThread().isInterrupted())
                        return;
                try {
                        Thread.sleep(sleepTime);
                } catch (InterruptedException e) {
                        Thread.currentThread().interrupt();
                }
        }
}

==> openjdk-26_26~32ea.orig.tar.xz: openjdk-26-26~32ea/test/hotspot/jtreg/vmTestbase/nsk/share/runner/MemDiag.java <==
/*
 * Copyright (c) 2007, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package nsk.share.runner;

/**
 *  Helper that prints memory information.
 */
public class MemDiag implements Runnable {
        private long sleepTime;

        public MemDiag() {
                this(RunParams.getInstance().getSleepTime());
        }

        public MemDiag(long sleepTime) {
                this.sleepTime = sleepTime;
        }

        public void run() {
                System.out.println(Runtime.getRuntime().freeMemory());
                // Ensure that interrupted status is not lost
                if (Thread.currentThread().isInterrupted())
                        return;
                try {
                        Thread.sleep(sleepTime);
                } catch (InterruptedException e) {
                        Thread.currentThread().interrupt();
                }
        }
}
